@@ -18,8 +18,8 @@ class TensorboardProvider(Provider):
         self.run_names = None
         self.logdir = None
 
-    def load(self, provider_args: List[str], workflow_name: Optional[str], provider_data: Dict[str, Any]):
-        super().load(provider_args, workflow_name, provider_data)
+    def load(self, provider_args: List[str], workflow_name: Optional[str], provider_data: Dict[str, Any], run_name: str):
+        super().load(provider_args, workflow_name, provider_data, run_name)
         self.before_run = self.provider_data.get("before_run")
         self.python = self._safe_python_version("python")
         self.version = self.provider_data.get("version")
