@@ -20,8 +20,8 @@ class BashProvider(Provider):
         self.commands = None
         self.image_name = None
 
-    def load(self, provider_args: List[str], workflow_name: Optional[str], provider_data: Dict[str, Any]):
-        super().load(provider_args, workflow_name, provider_data)
+    def load(self, provider_args: List[str], workflow_name: Optional[str], provider_data: Dict[str, Any], run_name: str):
+        super().load(provider_args, workflow_name, provider_data, run_name)
         self.before_run = self.provider_data.get("before_run")
         self.python = self._safe_python_version("python")
         self.commands = self.provider_data.get("commands")
@@ -43,8 +43,8 @@ class BashProvider(Provider):
 
     def parse_args(self):
         parser = self._create_parser(self.workflow_name)
-        args = parser.parse_args(self.provider_args)
-        self._parse_base_args(args)
+        args, unknown_args = parser.parse_known_args(self.provider_args)
+        self._parse_base_args(args, unknown_args)
         if self.run_as_provider:
             self.provider_data["commands"] = [args.command]
         if args.ports:
